function [x,phi,H]=efindxphi(V,D,w,L,E,A0,m,errtol)
% EFINDXPHI Calculates horizontal displacement, top end angle and
%       top end horizontal force of elastic catenary given
%       depth and top end vertical force.
%   Usage: [x,phi,H]=efindxphi(V,D,w,L,E,A0,m,errtol)
%
%   V      : Vertical force at top.
%   D      : Water depth.
%   w      : Weight per unit length in water. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   L      : Length of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   E      : Elastic modulus. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   A0     : Cross sectional area of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   m      : Weight in water for lump masses. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point. Thus, the first lump mass is attached
%          : to the anchor point, and is ignored, the second lump mass
%          : is attached to the intersection between the first and
%          : second segments, and so on.
%   errtol : Error tolerance.
%
%   x      : Horizontal displacement.
%   phi    : Angle at top end (relative to horizontal).
%   H      : Horizontal force at top point.
%
% Remarks:
%   This function is called by elastic1 and elastic2.
%
% References:
%   M.S. Triantafyllou: Cable Mechanics with Marine Applications.
%        Department of Ocean Engineering,
%        Massachusetts Institute of Technology, 1990.
%
%   O.M. Aamo: Adding mooring systems to the ABB IVS.
%        ABB 1999.

% Initialization
H=0;

% Number of segments
NS=length(w);

% First, check if the problem is solvable.
% Start with smallest possible angle.
phi=0.0001*pi/2;

% Calculate resulting horisontal and vertical displacements.
[x,z]=ecalcxzH(V,phi,w,L,E,A0,m,L(NS),[zeros(NS-1,1);1]);

if (z>D)
   % For the particular choice of V, even the smallest
   % value allowed for phi leads to z>D, so the
   % problem is not solvable for this V.
   % x=0 indicates unsolvable problem.
   x=0;
   return;
end

% Lower value for binary search.
phi1=phi;

% Next, do largest possible angle.
phi=0.9999*pi/2;

% Calculate resulting horizontal and vertical displacements.
[x,z]=ecalcxzH(V,phi,w,L,E,A0,m,L(NS),[zeros(NS-1,1);1]);

if (z<D)
   % For the particular choice of V, even the largest
   % value allowed for phi leads to z<D, so the
   % problem is not solvable for this V.
   % x=0 indicates unsolvable problem.
   x=0;
   return;
end

% Upper value for binary search.
phi2=phi;

% Initialize error.
err=errtol+1;

% Do binary search for the upper angle phi, that gives
% the desired depth, D.
while (err>errtol)
   % Next phi to check: average of lower and upper values.
   phi=0.5*(phi1+phi2);
   
   % Calculate resulting horizontal and vertical displacements,
   % as well as the upper horizontal force.
   [x,z,H]=ecalcxzH(V,phi,w,L,E,A0,m,L(NS),[zeros(NS-1,1);1]);
   
   if (D-z>0)
      % z is too small, so phi is new lower value.
      phi1=phi;
   else
      % z is too large, so phi is new upper value.
      phi2=phi;
   end
         
   % Calculate error
  	err=abs(D-z);
end

% Error is small enough, so return.
