%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% run_CSAD_NOES.m
%
% Project:	"Autonomous heading control in position mooring with thrust 
%           assist"
%
% Abstract:	This script runs a TAPM simulator of the CSAD including current
%           and waves. The control system includes a PID-controller, 
%           thrustallocation, reference system and a guidance system. 
%           A numerical optimization based ES controller is used in the 
%           autonomous guidance system to find the optimal heading.
%           The controller is switched of in surge and sway during this
%           verification.
%           
% Author:	Silje Aarvik Johannessen, Spring 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc;
clear all; 
close all;

% Loading system matrices
load moorLineProp_E.mat;
load CSAD_model.mat;
load CSAD_modelABC.mat;
initfile                    %thrust allocation parameters

%% FEM mooring system
% Parameters for the mooring system
NOfinite        =   50;
stiffSeafloor   =   2000;
anchorNum       =   8;
rBottomEnd      =   moorLineProp.bottomEnds;
E               =   moorLineProp.E;
d               =   moorLineProp.d;
L               =   moorLineProp.L;
numNode         =   moorLineProp.numNode;
rhoCab          =   moorLineProp.rhoCab;
rhoWat          =   moorLineProp.rhoWat;
emfact          =   moorLineProp.emfact;
Cmn             =   moorLineProp.Cmn;
Cdt             =   moorLineProp.Cdt;
Cdn             =   moorLineProp.Cdn;
tol             =   moorLineProp.tol;
waterDepth      =   moorLineProp.bottomEnds(3,:);

% Calculation of initial position of the mooring lines
depCur  =   [0;1000];      % surface->bootom
vel     =   [0.2;0.05;0.05];
dir     =   200*pi/180; %pi; 

for k=1:length(depCur)
    velCur(3*k-2:3*k)	=   [vel(k)*cos(dir);vel(k)*sin(dir);0];
end
rTopEnd  =   [0;0;0];
[rCatenary,V,H,V0,H0]       = initCable(moorLineProp,...
    rBottomEnd,...
    rTopEnd,...
    moorLineProp.tol);
r0      =   rCatenary(4:3*numNode,:);
r_dot0  =   zeros(3*numNode-3,anchorNum);

%% Desired heading
X_d = 0;
Y_d = 0;
des_pos = [X_d Y_d];

%% Controller gains
K_p_x   =   0; %4.7025; 
K_p_y   =   0; %5.8176; 
K_p_psi =   3.2626; 

K_d_x   =   0; %38.4727; 
K_d_y   =   0; %45.9263; 
K_d_psi =   21.8086; 

K_i_x   =   0; %0.0985;  
K_i_y   =   0; %0.1218;  
K_i_psi =   0.0683;

%% Reeference model
T_x      =   20/sqrt(90);
T_y      =   20/sqrt(90);
T_psi    =   35;

w_x      =   10; %1
w_y      =   10; %1
w_psi    =   10;

zeta_x   =   0.1; %0.5 
zeta_y   =   0.1; %0.5
zeta_psi =   0.1; 

%% Simulation
tend = 15000;    % Simulation time
sim CSAD_NOES

%% Plot

width=16;
height=13;
f = figure('Units','centimeters','Position',[0,0,width,height],'PaperPositionMode','auto');
h = subplot(2,2,1);
plot(eta.Time,eta.Data(:,6)*180/pi,SP.Time,SP.Data(:,3)*180/pi);
legend('\psi','\psi_{d}');
xlabel('Time [s]','interpreter','latex');
ylabel('$\psi$ [deg]','interpreter','latex');
title('Heading','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
h = subplot(2,2,2);
plot(J_new.Time,J_new.Data,J_av.Time,J_av.Data,'*');
xlabel('Time [s]','interpreter','latex');
ylabel('$J_{average}$','interpreter','latex');
title('$J_{average}$','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
h = subplot(2,2,3);
plot(tau_pid.Time,tau_pid.Data(:,3));
axis([0 15000 -0.05 0.05]);
xlabel('Time [s]','interpreter','latex');
ylabel('$\tau_{yaw}$ [Nm]','interpreter','latex');
title('Control moment in yaw','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
h = subplot(2,2,4);
plot(wave.Time,wave.Data(:,2),wave.Time,wave.Data(:,6));
%axis([0 20000 -0.2 0.2]);
xlabel('Time [s]','interpreter','latex');
ylabel('$\tau_{waves}$','interpreter','latex');
legend('Sway [N]','Yaw [Nm]');
title('Waves','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
set(f, 'PaperSize',[width, height]);
print(f, 'NOES_kun_200', '-dpdf');

width2=7.8;
height2=6.8;
f2 = figure('Units','centimeters','Position',[0,0,width2,height2],'PaperPositionMode','auto');
plot(eta.Time,eta.Data(:,6)*180/pi,SP.Time,SP.Data(:,3)*180/pi);
grid on;
legend('\psi','\psi_{d}','location', 'southeast');
xlabel('Time [s]','interpreter','latex');
ylabel('$\psi$ [deg]','interpreter','latex');
%title('Heading','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
set(f2, 'PaperSize',[width2, height2]);
print(f2, 'heading_noesK_200', '-dpdf');

f3 = figure('Units','centimeters','Position',[0,0,width2,height2],'PaperPositionMode','auto');
plot(J_new.Time,J_new.Data,J_av.Time,J_av.Data,'*');
grid on;
xlabel('Time [s]','interpreter','latex');
ylabel('$J_{average}$','interpreter','latex');
%title('$J_{average}$','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
set(f3, 'PaperSize',[width2, height2]);
print(f3, 'J_noesK_200', '-dpdf');

f4 = figure('Units','centimeters','Position',[0,0,width2,height2],'PaperPositionMode','auto');
plot(tau_pid.Time,tau_pid.Data(:,3));
grid on;
axis([0 15000 -0.05 0.05]);
xlabel('Time [s]','interpreter','latex');
ylabel('$\tau_{yaw}$ [Nm]','interpreter','latex');
%title('Control moment in yaw','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
set(f4, 'PaperSize',[width2, height2]);
print(f4, 'tau_noesK_200', '-dpdf');

f5 = figure('Units','centimeters','Position',[0,0,width2,height2],'PaperPositionMode','auto');
plot(wave.Time,wave.Data(:,2),wave.Time,wave.Data(:,6));
grid on;
%axis([0 20000 -0.2 0.2]);
xlabel('Time [s]','interpreter','latex');
ylabel('$\tau_{waves}$','interpreter','latex');
legend('Sway [N]','Yaw [Nm]','location', 'southeast');
%title('Waves','Interpreter','latex');
set(gca, 'TickLabelInterpreter','latex');
set(f5, 'PaperSize',[width2, height2]);
print(f5, 'wave_noesK_200', '-dpdf');