function  [rCatenary,V,H,V0,H0] = initCable(moorLineProp,rBottomEnd,rTopEnd,tol)
% [x,sfp]

%       E       ---
%       d       ---     diameter of the cable
%       A0      ---     area of the cable (A0=pi/4*d^2)
%       L       ---     length of the cable
%       numNode	---     number of the nodes (excluded the anchor)        
%       rhoCab	---     cable density
%       rhoWat	---     water density
%       emfact  ---     factor for stiffness calculation in the reaction force,[1,1], e.g. ef=1;
%       Cmn     ---     added mass coefficient in mass matrix, [1,1]
%       Cdt     ---     tangential drag coefficient in drag force, [1,1]
%       Cdn     ---     normal drag coefficient in drag force, [1,1]
%       bottomEnd	--- bottom point    [3,1]
%       topEnd      --- top point       [3,1]

%       emfact(ns)	--- emfact.
%       ks(ns)	---  	seafloor interaction spring konstant (N/m^2)

%   INITCABLE returns
%             x:     6*(sum(ne)+1) dimensional vector of nodal position triplets, and
%                    nodal velocity triplets.
%             sfp:   3*(sum(ne)+1) dimensional vector of touchdown point information
%                    (used internally in cable).
%
%   Reference:
%   Aamo,O.M. and Fossen,T.I. (1999): Finite Element Modelling of Moored Vessels.

E=moorLineProp.E;
d=moorLineProp.d;
L=moorLineProp.L;
numNode=moorLineProp.numNode;
rhoCab=moorLineProp.rhoCab;
rhoWat=moorLineProp.rhoWat;
emfact=moorLineProp.emfact;
Cmn=moorLineProp.Cmn;
Cdt=moorLineProp.Cdt;
Cdn=moorLineProp.Cdn;


g   =   9.81;                   % gravity acceleration (m/s^2)
A0  =   pi/4*d^2;               % area (m^2)
K	=   A0.*E.*emfact;          % cable stiffness
rho0=g*(rhoCab-rhoWat).*A0;     % weight in water
maxStrain   =   0.05;                     	% max strain.
bottomFicCoef	=   zeros(length(rho0),1);      % no bottom friction.
lampMass        =   zeros(length(rho0),1);      % no clump weights.

anchorNum       =   8;
i = 1;
rCatenary       =   zeros(3*numNode+3,anchorNum);

for i=1:1:anchorNum
    rBottomEnd_mid = rBottomEnd(:,i);

D       =   rBottomEnd_mid(3)-rTopEnd(3);      	% vertical displacement.
if D<=0
   te   =   sprintf('Bottom end should be lower than the top end. In the NED coordinate,z value for the anchors are positiove.');
   disp(te);
   return;
end

X   =   sqrt((rBottomEnd_mid(1)-rTopEnd(1))^2+(rBottomEnd_mid(2)-rTopEnd(2))^2); % horizontal displacement

% Construct s-vector of unstretched points along the cable
% for which to extract position information.
s   =   [0;[L/numNode:L/numNode:L]'];

% Calculate initial configuration, using elastic1.
[V,H,TD,V0,H0,x1,z,et]  =   elastic1(rho0,L,E,A0,emfact,bottomFicCoef,lampMass,D,X,maxStrain,s,numNode,tol);

% % If error: report and return.
% if (V==0)
%    te   =   sprintf('Call to elastic1 failed: %s\n',et);
%    disp(te);
%    return;
% end


% Transform to coordinates used in cable.
zNodeCatenary   =   [rBottomEnd_mid(3)-z; rTopEnd(3)];
xNodeCatenary   =   [rBottomEnd_mid(1)+x1*(rTopEnd(1)-rBottomEnd_mid(1))/X;rTopEnd(1)];
yNodeCatenary   =   [rBottomEnd_mid(2)+x1*(rTopEnd(2)-rBottomEnd_mid(2))/X;rTopEnd(2)];

% Stack into one vector, r:
rCatenary_mid                 	=   zeros(3*numNode+3,1);
rCatenary_mid(1:3:3*numNode+1)	=   xNodeCatenary;
rCatenary_mid(2:3:3*numNode+2)	=   yNodeCatenary;
rCatenary_mid(3:3:3*numNode+3)	=   zNodeCatenary;

rCatenary(:,i)                  =   rCatenary_mid;
end
end


