%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% run_CSAD_verification_openloop.m
%
%
% Project:	"Autonomous heading control in position mooring with thrust assist"
%
% Abstract:	This script is a verification of the open-loop system of the CSAD
%           simulator including a mooring model based on FEM. The vessel is 
%           exposed by waves and current.
%
% Author:	Silje Aarvik Johannessen, Spring 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc;
clear all; 
close all;

% Loading system matrices
load moorLineProp_E.mat;
load CSAD_model.mat;
load CSAD_modelABC.mat;

%% FEM mooring system
% Parameters for the mooring system
NOfinite        =   50;
stiffSeafloor   =   2000;
anchorNum       =   8;
rBottomEnd      =   moorLineProp.bottomEnds;
E               =   moorLineProp.E;
d               =   moorLineProp.d;
L               =   moorLineProp.L;
numNode         =   moorLineProp.numNode;
rhoCab          =   moorLineProp.rhoCab;
rhoWat          =   moorLineProp.rhoWat;
emfact          =   moorLineProp.emfact;
Cmn             =   moorLineProp.Cmn;
Cdt             =   moorLineProp.Cdt;
Cdn             =   moorLineProp.Cdn;
tol             =   moorLineProp.tol;
waterDepth      =   moorLineProp.bottomEnds(3,:);

% Calculation of initial position of the mooring lines
% Uniform
depCur  =   [0;1000];      % surface->bootom
vel     =   [0.2;0.05;0.05];
dir     =   200*pi/180;

for k=1:length(depCur)
    velCur(3*k-2:3*k)	=   [vel(k)*cos(dir);vel(k)*sin(dir);0];
end
rTopEnd  =   [0;0;0];
[rCatenary,V,H,V0,H0]       = initCable(moorLineProp,...
    rBottomEnd,...
    rTopEnd,...
    moorLineProp.tol);
r0      =   rCatenary(4:3*numNode,:);
r_dot0  =   zeros(3*numNode-3,anchorNum);

%% Desired thurust
desired_thrust = [0 0 0]'; 

%% Simulation
tend = 10000;                   % Simulation time
sim CSAD_verification_openloop

%% Plot
width=7.8;
height=8;
f = figure('Units','centimeters','Position',[0,0,width,height],'PaperPositionMode','auto');
h = subplot(3,1,1);
plot(eta.Time,eta.Data(:,1));
%axis([0 tend -0.6 0.1]);
ylabel('$X_E$ [m]','interpreter','latex');
%title('North position','Interpreter','latex')
grid on;
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,2);
plot(eta.Time,eta.Data(:,2));
%axis([0 10000 -1*10^-3 1*10^-3]);
ylabel('$Y_E$ [m]','interpreter','latex');
%title('East position','Interpreter','latex')
grid on;
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,3);
plot(eta.Time,eta.Data(:,6)*180/pi);
%axis([0 10000 -0.1 2*10^-1]);
%axis([0 10000 0 25]);
xlabel('Time [s]','interpreter','latex');
ylabel('$\psi$ [deg]','interpreter','latex');
%title('Heading','Interpreter','latex')
grid on;
set(gca, 'TickLabelInterpreter','latex');
set(f, 'PaperSize',[width, height]);
print(f, 'Position_open_200', '-dpdf');

f2 = figure('Units','centimeters','Position',[0,0,width,height],'PaperPositionMode','auto');
plot(eta.Data(:,2),eta.Data(:,1));
%axis([-0.01 0.01 -0.45 0.05]);
xlabel('East [m]','interpreter','latex');
ylabel('North [m]','interpreter','latex');
%title('North and East','Interpreter','latex')
grid on;
set(gca, 'TickLabelInterpreter','latex');
set(f2, 'PaperSize',[width, height]);
print(f2, 'NorthEast_open_200', '-dpdf');