%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% run_CSAD_SPES_SP.m
%
% Project:	"Autonomous heading control in position mooring with thrust 
%            assist"
%
% Abstract:	This script runs the CSAD simulator including current and
%           waves. The mooring model is simplified to be the linear model
%           defined in Chapter 4. The block thrustallocation is neglected
%           and assumed to be equal the forces and moments from the
%           controller. An autonomous guidance system based on the theory 
%           of sinusoidal perturbation based Extremum seeking is used for 
%           heading and setpoint chasing for surge and sway. 
%
% Author:	Silje Aarvik Johannessen, Spring 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc;
clear all; 
close all;

% Loading system matrices
load moorLineProp_E.mat;
load CSAD_model.mat;
load CSAD_modelABC_mooring.mat;

%% Controller gains
K_p_x   =   4.7025; 
K_p_y   =   5.8176; 
K_p_psi =   3.2626; 

K_d_x   =   38.4727; 
K_d_y   =   45.9263; 
K_d_psi =   21.8086; 

K_i_x   =   0; 
K_i_y   =   0;   
K_i_psi =   0.0683; 

%% Reeference model
T_x      =   20/sqrt(90);
T_y      =   20/sqrt(90);
T_psi    =   20/sqrt(90);

w_x      =   1; 
w_y      =   1;
w_psi    =   1; 

zeta_x   =   0.5; 
zeta_y   =   0.5; 
zeta_psi =   0.5; 

%% Extremum seeking
w = (2*pi)/1600;
wl = 0.4*w;
wh = 0.2*w;
k = 0.3;
a = 0.06;

%% Setpoint chasing
Ts = 20/sqrt(90);
Lambda = diag([1/Ts 1/Ts]);

%% Simulation 
tend = 150000;   % Simulation time
sim CSAD_SPES_SP

%% Plot
width=7.8;
height=10;
f = figure('Units','centimeters','Position',[0,0,width,height],'PaperPositionMode','auto');
h = subplot(3,1,1);
plot(eta.Time,eta.Data(:,1),SP.Time,SP.Data(:,1));
grid on;
legend('X_E','X_{Ed}');
ylabel('$X_E$ [m]','interpreter','latex');
axis([0 tend -0.8 0]);
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,2);
plot(eta.Time,eta.Data(:,2),SP.Time,SP.Data(:,2));
grid on;
legend('Y_E','Y_{Ed}');
ylabel('$Y_E$ [m]','interpreter','latex');
axis([0 tend -1.2 0]);
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,3);
plot(eta.Time,eta.Data(:,6)*180/pi,SP.Time,SP.Data(:,3)*180/pi);
grid on;
legend('\psi','\psi_{d}','location', 'Best');
xlabel('Time [s]','interpreter','latex');
ylabel('$\psi$ [deg]','interpreter','latex');
axis([0 tend -10 30]);
set(gca, 'TickLabelInterpreter','latex');
set(f, 'PaperSize',[width, height]);
print(f, 'Position_SP_ESP_200', '-dpdf');

f2 = figure('Units','centimeters','Position',[0,0,width,height],'PaperPositionMode','auto');
h = subplot(3,1,1);
plot(tau.Time,tau.Data(:,1));
grid on;
axis([0 tend -0.05 0.25]);
ylabel('$\tau_{surge}$ [N]','interpreter','latex');
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,2);
plot(tau.Time,tau.Data(:,2));
grid on;
%axis([0 tend -0.03 0.01]);
axis([0 tend -0.05 0.3]);
ylabel('$\tau_{sway}$ [N]','interpreter','latex');
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,3);
plot(tau.Time,tau.Data(:,3));
grid on;
%axis([0 tend -0.2 0.1]);
%axis([0 tend -0.1 0.1]);
xlabel('Time [s]','interpreter','latex');
ylabel('$\tau_{yaw}$ [Nm]','interpreter','latex');
set(gca, 'TickLabelInterpreter','latex');
set(f2, 'PaperSize',[width, height]);
print(f2, 'Tau_SP_ESP_200', '-dpdf');

width=7.8;
height=10;
f3 = figure('Units','centimeters','Position',[0,0,width,height],'PaperPositionMode','auto');
h = subplot(3,1,1);
plot(nu.Time,nu.Data(:,1));
grid on;
ylabel('u [m/s]','interpreter','latex');
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,2);
plot(nu.Time,nu.Data(:,2));
%axis([0 tend -0.0005 0.0005]);
grid on;
ylabel('v [m/s]','interpreter','latex');
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,3);
plot(nu.Time,nu.Data(:,6)*180/pi);
grid on;
xlabel('Time [s]','interpreter','latex');
ylabel('r [deg/s]','interpreter','latex');
set(gca, 'TickLabelInterpreter','latex');
set(f3, 'PaperSize',[width, height]);
print(f3, 'Vel_SP_ESP_200', '-dpdf');

width2=7.8;
height2=6.8;
f5 = figure('Units','centimeters','Position',[0,0,width2,height2],'PaperPositionMode','auto');
plot(wave.Time,wave.Data(:,1),wave.Time,wave.Data(:,2),wave.Time,wave.Data(:,6));
grid on;
legend('\tau_{1} [N]','\tau_{2} [N]','\tau_{6} [Nm]','location', 'Best');
%axis([0 tend -0.005 0.025]);
xlabel('Time [s]','interpreter','latex');
ylabel('$\tau_{wave}$','interpreter','latex');
%title('Environmental loads','Interpreter','latex');
set(gca, 'TickLabelInterpreter','latex');
set(f5, 'PaperSize',[width2, height2]);
print(f5, 'Wave_SP_ESP_200', '-dpdf');
