function [x,z,H]=ecalcxzH(V,phi,w,L,E,A0,m,s,ne)
% ECALCXZH Calculates horizontal and vertical displacement
%          and top point horizontal force of the elastic catenary
%          given top end vertical force and top end angle.
%   Usage: [x,z,H]=ecalcxzH(V,phi,w,L,E,A0,m,s,ne)
%
%   V      : Vertical force at top point.
%   phi    : Angle at top.
%   w      : Weight per unit length in water. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   L      : Length of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   E      : Elastic modulus. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   A0     : Cross sectional area of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   m      : Weight in water for lump masses. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point. Thus, the first lump mass is attached
%          : to the anchor point, and is ignored, the second lump mass
%          : is attached to the intersection between the first and
%          : second segments, and so on.
%   s      : Vector of s-values for which to return x and z values.
%          : The vector contains ne(1) values for the first segment,
%          : ne(2) values for the second segment and so on. Values
%          : for segment k must range from 0 to L(k).
%   ne     : Vector with one value for each segment. See description
%          : for s.
%
%   x      : Horizontal displacement.
%   z      : Vertical displacement.
%   H      : Horizontal force at top point.
%
% Remarks:
%   This function is called by elastic1.
%
% References:
%   M.S. Triantafyllou: Cable Mechanics with Marine Applications.
%        Department of Ocean Engineering,
%        Massachusetts Institute of Technology, 1990.
%
%   O.M. Aamo: Adding mooring systems to the ABB IVS.
%        ABB 1999.

% Number of segments
NS=length(w);

% Calculate horizontal force from prescribed vertical force and angle.
H=V/tan(phi);
   
% Initialize variables.
V0=V;
x=[];
z=[];

% Iterate through segments.
for sn=NS:-1:1,
   ss=s(1+sum(ne(1:sn-1)):sum(ne(1:sn)));
   
   % Make sure L is in ss.
   ss=[ss;L(sn)];
   
   % Calculate shape of cable.
   xn=H/w(sn)*(asinh((V0-w(sn)*(L(sn)-ss))/H)-asinh((V0-w(sn)*L(sn))/H))+H*ss/(E(sn)*A0(sn));
   zn=H/w(sn)*(sqrt(1+((V0-w(sn)*(L(sn)-ss))/H).^2)-sqrt(1+((V0-w(sn)*L(sn))/H)^2))+1/(E(sn)*A0(sn))*(V0*ss+w(sn)/2*((L(sn)-ss).^2-L(sn)^2));
   
   % Insert into the top of the x and z vectors.
   XN=length(xn);
   x=[xn(1:XN-1);x+xn(XN)];
   z=[zn(1:XN-1);z+zn(XN)];
   
   % Update V0.
   V0=V0-w(sn)*L(sn)-m(sn);
end
