function [V,H,TD,V0,H0,x,z,et]=elastic1(w,L,E,A0,emfact,my,m,D,X,me,s,ne,errtol)
% ELASTIC1 Calculates shape of elastic catenary.
%   Usage: [V,H,TD,H0,x,z,et]=elastic1(w,L,E,A0,my,m,D,X,me,s,ne,errtol)
%
%   w      : Weight per unit length in water. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   L      : Length of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   E      : Elastic modulus. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   A0     : Cross sectional area of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   emfact : Factor for stiffness calculation. 1=normal, 2=chain.
%   my     : Friction coefficient for bottom interaction. Vector, 
%          : consisting of one number per segment, ordered from
%          : the anchor towards the top point.
%   m      : Weight in water for lump masses. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point. Thus, the first lump mass is attached
%          : to the anchor point, and is ignored, the second lump mass
%          : is attached to the intersection between the first and
%          : second segments, and so on.
%   D      : Water depth.
%   X      : Horizontal distance between anchor point and top point.
%   me     : Max strain.
%   s      : Vector of s-values for which to return x and z values.
%          : The vector contains ne(1) values for the first segment,
%          : ne(2) values for the second segment and so on. Values
%          : for segment k must range from 0 to L(k).
%   ne     : Vector with one value for each segment. See description
%          : for s.
%   errtol : Error tolerance.
%
%   V      : Vertical force at top point.
%   H      : Horizontal force at top point.
%   TD     : Distance from anchor point to touchdown point along seafloor.
%   V0     : Vertical force at anchor.
%   H0     : Horizontal force at anchor.
%   x      : x-coordinate of points along the cable, corresponding to the
%          : values in s.
%   z      : z-coordinate of points along the cable, corresponding to the
%          : values in s.
%   et     : String with error message.
%
% Remarks:
%   The function solves the elastic catenary for a cable consisting
%   of an arbitrary number of segments with individual characteristics, for
%   prescribed anchor and top points. Weight per unit length in water is
%   assumed to be positive along the cable.
%   If the function fails, V will be zero, and an error message is
%   returned in the variable et.
%
% References:
%   M.S. Triantafyllou: Cable Mechanics with Marine Applications.
%        Department of Ocean Engineering,
%        Massachusetts Institute of Technology, 1990.
%
%   O.M. Aamo: Adding mooring systems to the ABB IVS.
%        ABB 1999.

% Initialize.
A0=A0.*emfact;
H0=0;
V0=0;
TD=0;
x=[0];
z=[0];

NS=length(w); % Number of segments.

% Solve the catenary.
[V,H,phi,i,Ls,et]=efindVHphi(w,L,E,A0,my,m,D,X,me,errtol);

% V=0 indicates unsolvable problem.

if (V~=0)
   if (i>0)
      % Divide the s vector at touchdown point.
      indl=sum(ne(1:i-1))+1; % Low index of touchdown segment.
      indh=sum(ne(1:i)); % High index of touchdown segment.
      
      % Find the index of the first s that is suspended.
      ind=indl;
      for j=indl:indh,
         if (s(j)>=L(i)-Ls)
            ind=j;
            break;
         end
      end
      
      % Now, divide the s vector at this index.
      sfl=s(1:ind-1);
      ssus=s(ind:sum(ne));
      
      % Make sure the seafloor array contains the last point,
      % otherwise we won't be able to "glue" the two parts
      % together correctly.
      sfl=[sfl;L(i)-Ls];
      ns=[ne(1:i-1);ind-sum(ne(1:i-1))];
      
      % Adjust the length of the suspended part.
      ssus(1:indh-ind+1)=ssus(1:indh-ind+1)-L(i)+Ls;
      nsu=[indh-ind+1;ne(i+1:NS)];
      
      % Calculate the seafloor points.
      L2=[L(1:i-1);L(i)-Ls];
      [xsf,H0]=ecalcsfx(H,w(1:i),L2,E(1:i),A0(1:i),my(1:i),sfl,ns);
      
      % Calculate the suspended points.
      L2=[Ls;L(i+1:NS)];
      [x,z]=ecalcxzH(V,phi,w(i:NS),L2,E(i:NS),A0(i:NS),m(i:NS),ssus,nsu);
      
      % "Glue" the points together.
      x=[xsf(1:ind-1);x+xsf(ind)];
      z=[zeros(ind-1,1);z];
      TD=xsf(ind);
   else
      [x,z]=ecalcxzH(V,phi,w,L,E,A0,m,s,ne);
      V0=V-sum(L.*w)-sum(m);
      H0=H;
   end
end
