%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% run_CSAD_setpointchasing.m
%
% Project:	"Autonomous heading control in position mooring with thrust 
%           assist"
%
% Abstract:	This script runs a TAPM simulator of the CSAD including current
%           and waves. The control system includes a PID-controller, 
%           thrustallocation, reference system and a guidance system. 
%           The setpoint chasing algorithm is used to autonomous find the 
%           optimal values for surge and sway. A user specified guidance
%           system is used to define the desired heading.
%           
% Author:	Silje Aarvik Johannessen, Spring 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc;
clear all; 
close all;

% Loading system matrices
load moorLineProp_E.mat;
load CSAD_model.mat;
load CSAD_modelABC.mat;
initfile                    %thrust allocation parameters

%% FEM mooring system
% Parameters for the mooring system
NOfinite        =   50;
stiffSeafloor   =   2000;
anchorNum       =   8;
rBottomEnd      =   moorLineProp.bottomEnds;
E               =   moorLineProp.E;
d               =   moorLineProp.d;
L               =   moorLineProp.L;
numNode         =   moorLineProp.numNode;
rhoCab          =   moorLineProp.rhoCab;
rhoWat          =   moorLineProp.rhoWat;
emfact          =   moorLineProp.emfact;
Cmn             =   moorLineProp.Cmn;
Cdt             =   moorLineProp.Cdt;
Cdn             =   moorLineProp.Cdn;
tol             =   moorLineProp.tol;
waterDepth      =   moorLineProp.bottomEnds(3,:);

% Calculation of initial position of the mooring lines
depCur  =   [0;1000];      % surface->bootom
vel     =   [0.2;0.05;0.05];
dir     =   200*pi/180; %pi; 

for k=1:length(depCur)
    velCur(3*k-2:3*k)	=   [vel(k)*cos(dir);vel(k)*sin(dir);0];
end
rTopEnd  =   [0;0;0];
[rCatenary,V,H,V0,H0]       = initCable(moorLineProp,...
    rBottomEnd,...
    rTopEnd,...
    moorLineProp.tol);
r0      =   rCatenary(4:3*numNode,:);
r_dot0  =   zeros(3*numNode-3,anchorNum);

%% Setpoint chasing
Ts = 20/sqrt(90);
Lambda = diag([1/Ts 1/Ts]);

%% Desired heading
des_heading = 20*(pi/180);

%% Controller gains
K_p_x   =   4.7025; 
K_p_y   =   5.8176; 
K_p_psi =   3.2626; 

K_d_x   =   38.4727; 
K_d_y   =   45.9263; 
K_d_psi =   21.8086; 

K_i_x   =   0; %0.0985;  
K_i_y   =   0; %0.1218;  
K_i_psi =   0.0683;

%% Reeference model
T_x      =   20/sqrt(90);
T_y      =   20/sqrt(90);
T_psi    =   35;

w_x      =   1; %10; %1
w_y      =   1; %10; %1
w_psi    =   10;

zeta_x   =   0.5; %0.1; %0.5 
zeta_y   =   0.5; %0.1; %0.5
zeta_psi =   0.1; 

%% Simulation
tend = 2000;    % Simulation time
sim CSAD_setpointchasing

%% Plot
width=7.8;
height=10;
f = figure('Units','centimeters','Position',[0,0,width,height],'PaperPositionMode','auto');
h = subplot(3,1,1);
plot(eta.Time,eta.Data(:,1),SP.Time,SP.Data(:,1));
grid on;
legend('X_E','X_{Ed}');
ylabel('$X_E$ [m]','interpreter','latex');
%title('North position','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,2);
plot(eta.Time,eta.Data(:,2),SP.Time,SP.Data(:,2));
grid on;
legend('Y_E','Y_{Ed}');
ylabel('$Y_E$ [m]','interpreter','latex');
%title('East position','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,3);
plot(eta.Time,eta.Data(:,6)*180/pi,SP.Time,SP.Data(:,3)*180/pi);
grid on;
legend('\psi','\psi_{d}');
xlabel('Time [s]','interpreter','latex');
ylabel('$\psi$ [deg]','interpreter','latex');
%title('Heading','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
set(f, 'PaperSize',[width, height]);
print(f, 'Position_SP_200', '-dpdf');

width2=7.8;
height2=10;
f2 = figure('Units','centimeters','Position',[0,0,width2,height2],'PaperPositionMode','auto');
h = subplot(3,1,1);
plot(tau_pid.Time,tau_pid.Data(:,1));
grid on;
axis([0 2000 -0.2 0.2]);
ylabel('$\tau_{surge}$ [N]','interpreter','latex');
%title('Control force in surge','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,2);
plot(tau_pid.Time,tau_pid.Data(:,2));
grid on;
axis([0 2000 -0.2 0.2]);
ylabel('$\tau_{sway}$ [N]','interpreter','latex');
%title('Control force in sway','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
h = subplot(3,1,3);
plot(tau_pid.Time,tau_pid.Data(:,3));
grid on;
axis([0 2000 -0.2 0.2]);
xlabel('Time [s]','interpreter','latex');
ylabel('$\tau_{yaw}$ [Nm]','interpreter','latex');
%title('Control moment in yaw','Interpreter','latex')
set(gca, 'TickLabelInterpreter','latex');
set(f2, 'PaperSize',[width2, height2]);
print(f2, 'Tau_SP_200', '-dpdf');