function [x,H0]=ecalcsfx(H,w,L,E,A0,my,s,ne)
% ECALCSFX Calculates horizontal displacement for the
%          part of the cable that lies along the
%          seafloor.
%   Usage: [x,H0]=ecalcsfx(H,w,L,E,A0,my,s,ne)
%
%   H      : Horizontal force at touchdown point.
%   w      : Weight per unit length in water. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   L      : Length of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   E      : Elastic modulus. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   A0     : Cross sectional area of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   my     : Friction coefficient for bottom interaction. Vector, 
%          : consisting of one number per segment, ordered from
%          : the anchor towards the top point.
%   s      : Vector of s-values for which to return x and z values.
%          : The vector contains ne(1) values for the first segment,
%          : ne(2) values for the second segment and so on. Values
%          : for segment k must range from 0 to L(k).
%   ne     : Vector with one value for each segment. See description
%          : for s.
%
%   x      : Horizontal displacement.
%   H0     : Horizontal force at anchor point.
%
% Remarks:
%   This function is called by elastic1.
%
% References:
%   M.S. Triantafyllou: Cable Mechanics with Marine Applications.
%        Department of Ocean Engineering,
%        Massachusetts Institute of Technology, 1990.
%
%   O.M. Aamo: Adding mooring systems to the ABB IVS.
%        ABB 1999.

% Number of segments.
NS=length(w);

% Initialize variables.
x=[];
z=[];
H0=H;
Hn=0;

% Step through the segments.
for sn=NS:-1:1,
   % The tension in the segment decays linearly due
   % to friction, until the tension is zero.
   if (H0>0)
      Hn=H0-L(sn)*my(sn)*w(sn);
   end
   
   if (Hn<0)
      % Find length where H becomes zero:
      Lz=L(sn)-H0/(my(sn)*w(sn));
      
      % Divide the s vector at zero point.
      indl=sum(ne(1:sn-1))+1; % Low index of current segment.
      indh=sum(ne(1:sn)); % High index of current segment.
      
      % Find the index of the first s that has positive strain.
      ind=indl;
      for j=indl:indh,
         if (s(j)>=Lz)
            ind=j;
            break;
         end
      end
      
      % Now, divide the s vector at this index.
      se0=s(indl:ind-1);
      sep=s(ind:indh);
      
      % Adjust the elements in sep, and make sure max L is in there.
      Lsm=L(sn)-Lz;
      ss=[sep-Lz;Lsm];
      
		xn=ss+(H0*ss+0.5*my(sn)*w(sn)*((Lsm-ss).^2-Lsm^2))/(E(sn)*A0(sn));
      
      % Insert into the top of the x vector.
   	XN=length(xn);
      x=[xn(1:XN-1);x+xn(XN)];
      
      % Add the strainless part.
      x=[se0;x+Lz];
      H0=0;
   elseif (H0==0)
      % Add strainless parts.
      ss=s(1+sum(ne(1:sn-1)):sum(ne(1:sn)));
      x=[ss;x+L(sn)];
   else
      ss=s(1+sum(ne(1:sn-1)):sum(ne(1:sn)));
      
      % Make sure L is in ss.
      ss=[ss;L(sn)];

		xn=ss+(H0*ss+0.5*my(sn)*w(sn)*((L(sn)-ss).^2-L(sn)^2))/(E(sn)*A0(sn));
      
      % Insert into the top of the x vector.
   	XN=length(xn);
      x=[xn(1:XN-1);x+xn(XN)];
      H0=Hn;
   end
end
