function [V,H,phi,i,Ls,et]=efindVHphi(w,L,E,A0,my,m,D,X,me,errtol)
% EFINDVHPHI Calculates the upper end forces of the elastic catenary.
%   Usage: [V,H,phi,i,Ls,et]=efindVHphi(w,L,E,A0,my,m,D,X,me,errtol)
%
%   w      : Weight per unit length in water. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   L      : Length of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   E      : Elastic modulus. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   A0     : Cross sectional area of the cable. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point.
%   my     : Friction coefficient for bottom interaction. Vector, 
%          : consisting of one number per segment, ordered from
%          : the anchor towards the top point.
%   m      : Weight in water for lump masses. Vector, consisting of
%          : one number per segment, ordered from the anchor towards
%          : the top point. Thus, the first lump mass is attached
%          : to the anchor point, and is ignored, the second lump mass
%          : is attached to the intersection between the first and
%          : second segments, and so on.
%   D      : Water depth.
%   X      : Horizontal distance between anchor point and top point.
%   me     : Max strain.
%   errtol : Error tolerance.
%
%   V      : Vertical force at top point.
%   H      : Horizontal force at top point.
%   phi    : Angle of the cable relative to horizontal at the top point.
%   i      : Index of segment that has touchdown point. Zero if no touchdown point.
%   Ls     : Length of suspended part of segment that has touchdown point.
%   et     : String with error message.
%
% Remarks:
%   This function is called by elastic1.
%
% References:
%   M.S. Triantafyllou: Cable Mechanics with Marine Applications.
%        Department of Ocean Engineering,
%        Massachusetts Institute of Technology, 1990.
%
%   O.M. Aamo: Adding mooring systems to the ABB IVS.
%        ABB 1999.

% Assume problem unsolvable by setting V and H equal to zero.
V=0;
H=0;
phi=0;
i=0;
Ls=0;
et='';

NS=length(w); % Number of segments.

% Disregard point mass at end.
m(1)=0;

% We will do a binary search on the top vertical force. So we need to find
% upper and lower bounds for V, that at the same time are feasible values.
% Start with upper bound, guess the total weight.
v2=w'*L+sum(m);

% Find x and phi for this vertical force.
[x,phi]=efindxphi(v2,D,w,L,E,A0,m,errtol);

% If x is larger than the desired horizontal displacement,
% then we're ok. Otherwise, the anchor point will have
% vertical load, that is, no touchdown point.
if (x<X)
   % Note that in this case, v2 is a lower bound for V.
   v1=v2;
   
   % Now, gradually increase v2, until x is
   % larger than the desired X, or until
   % the average strain exceeds the max value me.
   while (x<X)
      v2=1.1*v2;
      [x,phi]=efindxphi(v2,D,w,L,E,A0,m,errtol);
      
      if (sum(L)*(1+me)<sqrt(x^2+D^2))
         % Strain too high.
         et='ERROR: Average strain is too high.';
         return;
      end
   end
else
   % In this case, our guess for an upper bound for V
   % was ok.
   % We now check if the cable is too long.
   if (sum(L)>X+D)
      % The cable is too long.
      et='ERROR: The cable is too long.';
      return;
   end
      
   % We proceed to find a lower bound for V.
   % As a lower bound for V, we choose the weight of the
   % upper cable part of length D.
   v1=0;
   Lt=0;
   for sn=NS:-1:1,
      if (Lt+L(sn)>D)
         v1=v1+(D-Lt)*w(sn);
         break;
      else
         Lt=Lt+L(sn);
         v1=v1+L(sn)*w(sn)+m(sn);
      end
   end
end

% We have found lower and upper bounds for V
% which are feasible. Start the binary search for V.

% Initialize error.         
err=errtol+1;
     
while (err>errtol)
   % Next value for V: average of upper and lower bounds.
   V=0.5*(v1+v2);
        
   % Calculate suspended length of cable, and
   % index of touchdown segment.
   V0=V;
   i=0;
   Ls=[];
   for sn=NS:-1:1,
      % Subtract weight of segment.
      V0=V0-w(sn)*L(sn);
      % Subtract weight of buoy.
      if (m(sn)<0)
         V0=V0-m(sn);
      end
      
      % If V0 is negative, then touchdown has occurred.
      if (V0<=0)
         % Touchdown for segment sn.
         i=sn;
         Ls=L(sn)+V0/w(sn); % Length of suspended
                            % part of segment i.
         break;
      end
      % Subtract weight of clump weight.
      if (m(sn)>0)
         V0=V0-m(sn);
      end
   end
   
   % Calculate total x.
   
   if (i==0)
      [x,phi,H]=efindxphi(V,D,w,L,E,A0,m,errtol);
   else
      % First, the suspended part.
      L2=[Ls;L(i+1:NS)];
      [x,phi,H]=efindxphi(V,D,w(i:NS),L2,E(i:NS),A0(i:NS),m(i:NS),errtol);
      
      if (x==0)
	      % The cable is too long.
         et='ERROR: The cable is too long.';
         V=0;
      	return;
	   end
      
      % Then, the seafloor part.
      H0=H;
      if (i>0)
         L2=[L(1:i-1);L(i)-Ls];
         [xsf,H0]=ecalcsfx(H,w(1:i),L2,E(1:i),A0(1:i),my(1:i),L2(i),[zeros(i-1,1);1]);
         x=x+xsf;
      end
   end
   % Calculate error.
   err=abs(v1-v2);
            
   if (x-X>0)
      % x is larger than the desired horizontal 
      % displacement, so V is a new upper
      % bound.
      v2=V;
   else
      % x is smaller than the desired horizontal 
      % displacement, so V is a new lower
      % bound.
      v1=V;
   end
end
